@@ -339,7 +339,30 @@ func (t *Transpiler) input() {
 				},
 			)
 		case *embeddedsass.OutboundMessage_LogEvent_:
-			// Drop these for now.
+			if t.opts.LogEventHandler != nil {
+				var logEvent LogEvent
+				e := c.LogEvent
+				if e.Span != nil {
+					u := e.Span.Url
+					if u == "" {
+						u = "stdin"
+					}
+					u, _ = url.QueryUnescape(u)
+					logEvent = LogEvent{
+						Type:    LogEventType(e.Type),
+						Message: fmt.Sprintf("%s:%d:%d: %s", u, e.Span.Start.Line, e.Span.Start.Column, c.LogEvent.GetMessage()),
+					}
+				} else {
+					logEvent = LogEvent{
+						Type:    LogEventType(e.Type),
+						Message: e.GetMessage(),
+					}
+				}
+
+				t.opts.LogEventHandler(logEvent)
+
+			}
+
 		case *embeddedsass.OutboundMessage_Error:
 			err = fmt.Errorf("SASS error: %s", c.Error.GetMessage())
 		default:
